#
# spec file for package rapidjson
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           rapidjson
Version:        1.1.0+git20211015.4d6cb081
Release:        1.5
Summary:        JSON parser and generator for C++
License:        MIT
Group:          Development/Libraries/C and C++
URL:            http://rapidjson.org/
Source0:        %{name}-%{version}.tar.xz
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig

%description
RapidJSON is a JSON parser and generator for C++. It was inspired by RapidXml.

* It supports both SAX and DOM style API. The SAX parser is only a
  half thousand lines of code.
* It optionally supports SSE2/SSE4.2 for acceleration.
* Header-only implementation. It does not depend on STL.
* Each JSON value occupies exactly 16/20 bytes for most 32/64-bit
  machines (excluding text string). By default, it uses a memory
  allocator, and the parser allocates memory compactly during
  parsing.
* It supports UTF-8, UTF-16, UTF-32 (LE & BE), and their detection,
  validation and transcoding internally. For example, you can read a
  UTF-8 file and let RapidJSON transcode the JSON strings into UTF-16
  in the DOM. It also supports surrogates and "\u0000" (null
  character).

%package devel
Summary:        Header files for rapidjson, a JSON parser and generator for C++
Group:          Development/Libraries/C and C++
Provides:       %{name} = %{version}

%description devel
RapidJSON is a header-only JSON parser and generator for C++.
This package contains development headers and examples.

%prep
%setup -q
sed -i -e 's:-Werror::g' CMakeLists.txt

%build
%cmake \
  -DDOC_INSTALL_DIR=%{_docdir}/%{name}-devel \
  -DRAPIDJSON_BUILD_TESTS=ON \
  -DRAPIDJSON_ENABLE_INSTRUMENTATION_OPT=OFF
%cmake_build

%install
%cmake_install

%files devel
%doc CHANGELOG.md readme.md
%license license.txt
%dir %{_docdir}/%{name}-devel
%{_docdir}/%{name}-devel/*
%{_includedir}/rapidjson/
%{_libdir}/cmake/RapidJSON/
%{_libdir}/pkgconfig/*.pc

%changelog
* Fri Jan 14 2022 Ben Greiner <code@bnavigator.de>
- Update to version 1.1.0+git20211015.4d6cb081
  * using the git commit referenced by python-rapidjson
  * see also changelog entry from Jun 06 2019 about the reasoning
* Wed Jun 12 2019 Tomáš Chvátal <tchvatal@suse.com>
- Remove bundled gtest and do not test as the testing only
  works with bundled gtest version
* Thu Jun  6 2019 tchvatal@suse.com
- Switch to _service as upstream didn't release since 2016 and we
  would need to backport many more features to make ie python-rapidjson
  working
- Update to version 1.1.0+git20190517.4b3d7c2f:
  * Add missing curly brackets in STDREGEX's CreatePattern().
  * fix typo
  * add missing header "ios"
  * doc/tutorial.zh-cn: fixed some typos
  * Update allocators.h
- Remove pateches for the old version:
  * fix_compilation_gcc7.patch
  * fix_compilation_sle11sp4.patch
  * fix_install_paths.patch
  * ignore_gcc8_warnings.patch
  * remove_arch_specific_flags.patch
* Wed Dec 12 2018 Jan Engelhardt <jengelh@inai.de>
- Trim bias from description.
* Tue Dec 11 2018 mmnelemane@suse.com
- Fix build for SLE_12_SP2:
  * use %%doc for license file to fix build for older distro
* Mon Jun 18 2018 christophe@krop.fr
- Add upstream's patch ignore_gcc8_warnings.patch.
* Fri Jun  2 2017 christophe@krop.fr
- Add fix_compilation_gcc7.patch. Fixes build with GCC >= 7.0
* Mon Oct 10 2016 adam.majer@suse.de
- Added BuildRoot so we can actually build for SLE11
* Fri Sep 30 2016 adam.majer@suse.de
- New upstream version 1.1.0
  * Added JSON Pointer
  * Added JSON Schema
  * Added relaxed JSON syntax (comment, trailing comma,
    NaN/Infinity)
  * Iterating array/object with C++11 Range-based for loop
  * Reduce memory overhead of each Value from 24 bytes to 16 bytes
    in x86-64 architecture.
  * full changeset at
    https://github.com/miloyip/rapidjson/releases/tag/v1.1.0
- remove_arch_specific_flags.patch: remove architecture specific
  compiler flags.
- merge doc into devel package, it only adds about 20kB
* Wed Apr 20 2016 tbechtold@suse.com
- Initial packaging (version 1.0.2)
